@@ -8,7 +8,7 @@ from evernote.edam.type.ttypes import Resource, ResourceAttributes, Data
 from xml.sax.saxutils import escape
 from datetime import datetime
 from clint import textui
-import sys, os, argparse, mimetypes, hashlib, ConfigParser
+import sys, os, argparse, mimetypes, hashlib, ConfigParser, copy
 import keyring
 import chardet
 import config as sys_config
@@ -22,8 +22,9 @@ class ToEver():
         self.share = False
         self.tag = None
         self.bookguid = None
+        self.content = str()
 
-    def createNote(self, title, content, resource=None):
+    def createNote(self, title, resource=None):
         user_store = self.client.get_user_store()
         note_store = self.client.get_note_store()
         try:
@@ -32,14 +33,14 @@ class ToEver():
             note.notebookGuid = self.bookguid
             if resource is not None:
                 note.resources = [resource]
-                content += "<span><en-media type=\"%s\" hash=\"%s\"/></span>" % (resource.mime, resource.data.bodyHash)
+                self.content += "<span><en-media type=\"%s\" hash=\"%s\"/></span>" % (resource.mime, resource.data.bodyHash)
             note.title = title
             note.content = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
             note.content += "<!DOCTYPE en-note SYSTEM \"http://xml.evernote.com/pub/enml2.dtd\">"
-            note.content += "<en-note>%s</en-note>" % content
+            note.content += "<en-note>%s</en-note>" % self.content
             created_note = note_store.createNote(note)
         except:
-            return textui.colored.red('Create note error')
+            return False
 
         note_share_url = None
         note_share_resource_url = None
@@ -54,17 +55,43 @@ class ToEver():
                 for x in created_note.resources:
                     note_share_resource_url = note_share_url + "/res/%s/%s" % (x.guid, x.attributes.fileName)
 
+        message = None
         if not self.hide:
-            message = "\n" + "Created note title is '" + title + "'"
+            message = "Created note title is '" + title + "'"
             message += " [" + ToEver.getUserUploadState(note_store.getSyncState().uploaded, user_store.getUser().accounting.uploadLimitNextMonth) + "]"
             if note_share_url is not None:
                 message += "\n" + "share link --> " + note_share_url
                 if note_share_resource_url is not None:
                     message += "\n" + "share attachment link --> " + note_share_resource_url
-            print(textui.colored.blue(message))
         elif note_share_url is not None:
-            print(textui.colored.blue(note_share_url))
-        return 0
+            message = note_share_url
+            if note_share_resource_url is not None:
+                message += "\n" + note_share_resource_url
+        if message is not None:
+            print(textui.colored.blue(message))
+        return True
+
+    def getResource(self, filename):
+        data = Data()
+        data.body = sys.stdin.read()
+        data.size = len(data.body)
+        data.bodyHash = hashlib.md5(data.body).hexdigest()
+        resource = Resource()
+        resource.mime = mimetypes.guess_type(filename)[0]
+        resource.data = data
+        attr = ResourceAttributes()
+        attr.fileName = filename
+        resource.attributes = attr
+        return resource
+
+    def setContent(self):
+        for line in iter(sys.stdin.readline, ''):
+            self.content += self.getContentFormat(line)
+            if not self.hide:
+                print(textui.colored.green(line.rstrip()))
+
+    def isSetContent(self):
+        return len(self.content.replace('<div><br/></div>', '')) != 0
 
     def listNotebooks(self):
         note_store = self.client.get_note_store()
@@ -79,10 +106,6 @@ class ToEver():
         data = data.replace('<div></div>', '<div><br/></div>') + '\n'
         return data
 
-    @staticmethod
-    def isSetContent(data):
-        return len(data.replace('<div><br/></div>', '')) != 0
-
     @staticmethod
     def getNoteShareUrl(url, shard_id, note_guid, share_key):
         return "%s/shard/%s/sh/%s/%s" % (url, shard_id, note_guid, share_key)
@@ -158,7 +181,7 @@ class Util():
 
 def main():
     parser = argparse.ArgumentParser(description=sys_config.application_name + ' version ' + sys_config.version)
-    parser.add_argument('file', nargs='?', action='store', help='file to send to evernote')
+    parser.add_argument('file', nargs='*', action='store', help='file to send to evernote')
     parser.add_argument('-t', '--title', type=str, help='set note title (omitted, the time is inputted automatically.)')
     parser.add_argument('-f', '--filename', type=str, help='set note attachment file name (When the name is designated, it processed as attachment file.)')
     parser.add_argument('--tags', type=str, help='set note tags (multiple tag separated by comma.)')
@@ -171,7 +194,6 @@ def main():
     args = parser.parse_args()
     user_config = UserConfig(sys_config.user_filepath)
 
-    # Set user config
     if args.config:
         try:
             user_config.setDeveloperToken().setDefaultNotebook().setDefaultTags().save()
@@ -179,15 +201,6 @@ def main():
             return 1
         return 0
 
-    # File check
-    if args.file is not None:
-        if not os.path.isfile(args.file):
-            return textui.colored.red('File does not exist ' + args.file)
-        sys.stdin = open(args.file, 'r')
-        if Util.isBinary(open(args.file, 'r').read()) and args.filename is None:
-            args.filename = os.path.basename(args.file)
-
-    # Get user developer token
     stdin_dafault = sys.stdin
     sys.stdin = open('/dev/tty', 'rt')
     if not user_config.isDeveloperToken(keyring.get_password(sys_config.application_name, 'developer_token'), sys_config.sandbox):
@@ -196,17 +209,14 @@ def main():
 
     toever = ToEver(keyring.get_password(sys_config.application_name, 'developer_token'), sys_config.sandbox)
 
-    # Get note title
     if args.title is None:
         args.title = 'toEver Post ' + datetime.now().strftime('%Y-%m-%d %H:%M:%S')
 
-    # Get note tags
     if args.tags is None and user_config.getUserOption('tags'):
         args.tags = user_config.getUserOption('tags')
     if args.tags is not None:
         toever.tag = args.tags.split(',')
 
-    # Set note bookguid
     if args.notebook is None and user_config.getUserOption('notebook'):
         args.notebook = user_config.getUserOption('notebook')
     if args.notebook is not None:
@@ -215,43 +225,42 @@ def main():
                 toever.bookguid = line.guid
                 break
 
-    # Set note tags share
     toever.hide = args.hide
     toever.share = args.share
 
-    # Set note content
-    note_content = str()
+    if len(args.file) > 0:
+        for filepath in args.file:
+            if filepath is not None:
+                if not os.path.isfile(filepath):
+                    return textui.colored.red('File does not exist ' + filepath)
+                sys.stdin = open(filepath, 'r')
+                resource = None
+                if Util.isBinary(open(filepath, 'r').read()) and args.filename is None:
+                    filename = os.path.basename(filepath)
+                    resource = toever.getResource(filename)
+                    if not toever.hide:
+                        print(textui.colored.green("Attachment file is '" + filename + "'"))
+                else:
+                    toever.setContent()
+                if not toever.createNote(args.title, resource):
+                    return textui.colored.red('Create note error')
+        return 0
 
-    # Set binary stream
     if args.filename is not None:
-        data = Data()
-        data.body = sys.stdin.read()
-        data.size = len(data.body)
-        data.bodyHash = hashlib.md5(data.body).hexdigest()
-        resource = Resource()
-        resource.mime = mimetypes.guess_type(args.filename)[0]
-        resource.data = data
-        attr = ResourceAttributes()
-        attr.fileName = args.filename
-        resource.attributes = attr
-        if not args.hide:
-            print(textui.colored.green("Attachment file is '" + attr.fileName + "'"))
-        return toever.createNote(args.title, note_content, resource)
+        if not toever.hide:
+            print(textui.colored.green("Attachment file is '" + args.filename + "'"))
+        if not toever.createNote(args.title, toever.getResource(args.filename)):
+            return textui.colored.red('Create note error')
+        return 0
 
-    # Set text stream
     try:
-        for line in iter(sys.stdin.readline, ''):
-            note_content += toever.getContentFormat(line)
-            if not args.hide:
-                print(textui.colored.green(line.rstrip()))
+        toever.setContent()
     except:
         pass
     finally:
-        # create note
-        if toever.isSetContent(note_content):
-            return toever.createNote(args.title, note_content)
-    return textui.colored.red('Create note error')
-
+        if not toever.createNote(args.title):
+            return textui.colored.red('Create note error')
+    return 0
 
 if __name__ == "__main__":
     sys.exit(main())
